Module blaxel.core.client.models.memory_allocation_by_name
==========================================================

Classes
-------

`MemoryAllocationByName(allocation: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Memory allocation by service name
    
    Attributes:
        allocation (Union[Unset, float]): Memory allocation value
        name (Union[Unset, str]): Name
    
    Method generated by attrs for class MemoryAllocationByName.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `allocation: blaxel.core.client.types.Unset | float`
    :

    `name: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :